Struct bracket_color::color_pair::ColorPair
source · pub struct ColorPair {
pub fg: RGBA,
pub bg: RGBA,
}Expand description
Represents two colors together, a foreground and a background. Frequently used to represent a glyph rendered on a console with a solid background color.
Fields
fg: RGBAThe foreground color
bg: RGBAThe background color
Implementations